# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`reprepro`](#reprepro): Configures reprepro on a server

### Defined types

* [`reprepro::distribution`](#repreprodistribution): Adds a "Distribution" to manage.
* [`reprepro::filterlist`](#repreprofilterlist): Adds a FilterList  Packages list have the same syntax as the output of dpkg --get-selections
* [`reprepro::key`](#repreprokey): Import a PGP key into the local keyring of the reprepro user
* [`reprepro::pull`](#reprepropull): Add a repository pull rule.
* [`reprepro::repository`](#repreprorepository): Adds a packages repository.
* [`reprepro::update`](#repreproupdate): Adds a packages repository.

## Classes

### <a name="reprepro"></a>`reprepro`

Configures reprepro on a server

#### Parameters

The following parameters are available in the `reprepro` class:

* [`basedir`](#basedir)
* [`homedir`](#homedir)
* [`manage_user`](#manage_user)
* [`user_name`](#user_name)
* [`group_name`](#group_name)
* [`keys`](#keys)
* [`key_defaults`](#key_defaults)
* [`repositories`](#repositories)
* [`repositories_defaults`](#repositories_defaults)
* [`package_ensure`](#package_ensure)
* [`package_name`](#package_name)
* [`distributions_defaults`](#distributions_defaults)

##### <a name="basedir"></a>`basedir`

Data type: `String`

The base directory to house the repository.

Default value: `'/var/packages'`

##### <a name="homedir"></a>`homedir`

Data type: `String`

The home directory of the reprepro user.

Default value: `'/var/packages'`

##### <a name="manage_user"></a>`manage_user`

Data type: `Boolean`

if true, creates the user $user_name

Default value: ``true``

##### <a name="user_name"></a>`user_name`

Data type: `String`

user_name who own reprepro

Default value: `'reprepro'`

##### <a name="group_name"></a>`group_name`

Data type: `String`

group of user who own reprepro

Default value: `'reprepro'`

##### <a name="keys"></a>`keys`

Data type: `Hash`

hash to create reprepro::key resources.

Default value: `{}`

##### <a name="key_defaults"></a>`key_defaults`

Data type: `Hash`

hash with defaults for keys creation.

Default value: `{}`

##### <a name="repositories"></a>`repositories`

Data type: `Hash`

hash to create reprepro::repository resources.

Default value: `{}`

##### <a name="repositories_defaults"></a>`repositories_defaults`

Data type: `Hash`

hash with defaults for reporitories creation.

Default value: `{}`

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String`

what to ensure for packages

Default value: `'present'`

##### <a name="package_name"></a>`package_name`

Data type: `String`

name of the package to install

Default value: `'reprepro'`

##### <a name="distributions_defaults"></a>`distributions_defaults`

Data type: `Hash`

defaults to use for all distributions.
they may got overwritten from the repositories
distribution_defaults

Default value: `{}`

## Defined types

### <a name="repreprodistribution"></a>`reprepro::distribution`

Adds a "Distribution" to manage.

#### Examples

##### 

```puppet
reprepro::distribution {"lenny":
  repository    => "my-repository",
  origin        => "Camptocamp",
  label         => "Camptocamp",
  suite         => "stable",
  architectures => "i386 amd64 source",
  components    => "main contrib non-free",
  description   => "A simple example of repository distribution",
  sign_with     => "packages@camptocamp.com",
}
```

#### Parameters

The following parameters are available in the `reprepro::distribution` defined type:

* [`repository`](#repository)
* [`version`](#version)
* [`origin`](#origin)
* [`label`](#label)
* [`suite`](#suite)
* [`architectures`](#architectures)
* [`components`](#components)
* [`description`](#description)
* [`sign_with`](#sign_with)
* [`codename`](#codename)
* [`fakecomponentprefix`](#fakecomponentprefix)
* [`udebcomponents`](#udebcomponents)
* [`deb_indices`](#deb_indices)
* [`dsc_indices`](#dsc_indices)
* [`update`](#update)
* [`pull`](#pull)
* [`uploaders`](#uploaders)
* [`snapshots`](#snapshots)
* [`install_cron`](#install_cron)
* [`not_automatic`](#not_automatic)
* [`but_automatic_upgrades`](#but_automatic_upgrades)
* [`log`](#log)
* [`create_pull`](#create_pull)
* [`create_update`](#create_update)
* [`create_filterlist`](#create_filterlist)

##### <a name="repository"></a>`repository`

Data type: `String`

the name of the repository to attach this
distribution to.

##### <a name="version"></a>`version`

Data type: `Optional[String]`

distribution version

Default value: ``undef``

##### <a name="origin"></a>`origin`

Data type: `Optional[String]`

package origin

Default value: ``undef``

##### <a name="label"></a>`label`

Data type: `Optional[String]`

package label

Default value: ``undef``

##### <a name="suite"></a>`suite`

Data type: `Optional[String]`

package suite

Default value: ``undef``

##### <a name="architectures"></a>`architectures`

Data type: `String`

available architectures

##### <a name="components"></a>`components`

Data type: `String`

available components

##### <a name="description"></a>`description`

Data type: `Optional[String]`

a short description

Default value: ``undef``

##### <a name="sign_with"></a>`sign_with`

Data type: `String`

email of the gpg key

Default value: `''`

##### <a name="codename"></a>`codename`

Data type: `String`

codename (defaults to $title)

Default value: `$title`

##### <a name="fakecomponentprefix"></a>`fakecomponentprefix`

Data type: `Optional[String]`

fakecomponentprefix

Default value: ``undef``

##### <a name="udebcomponents"></a>`udebcomponents`

Data type: `String`

udebcomponents

Default value: `$components`

##### <a name="deb_indices"></a>`deb_indices`

Data type: `String`

file name and compression

Default value: `'Packages Release .gz .bz2'`

##### <a name="dsc_indices"></a>`dsc_indices`

Data type: `String`

file name and compression

Default value: `'Sources Release .gz .bz2'`

##### <a name="update"></a>`update`

Data type: `String`

update policy name

Default value: `''`

##### <a name="pull"></a>`pull`

Data type: `String`

pull policy name

Default value: `''`

##### <a name="uploaders"></a>`uploaders`

Data type: `String`

who is allowed to upload packages

Default value: `''`

##### <a name="snapshots"></a>`snapshots`

Data type: `Boolean`

create a reprepro snapshot on each update

Default value: ``false``

##### <a name="install_cron"></a>`install_cron`

Data type: `Boolean`

install cron job to automatically include new packages

Default value: ``true``

##### <a name="not_automatic"></a>`not_automatic`

Data type: `String`

automatic pined to 1 by using NotAutomatic,
value are "yes" or "no"

Default value: `''`

##### <a name="but_automatic_upgrades"></a>`but_automatic_upgrades`

Data type: `String`

set ButAutomaticUpgrades,
value are "yes" or "no"

Default value: `'no'`

##### <a name="log"></a>`log`

Data type: `String`

log

Default value: `''`

##### <a name="create_pull"></a>`create_pull`

Data type: `Hash`

hash to create reprepro::pull resource
the name will be appended to $pull

Default value: `{}`

##### <a name="create_update"></a>`create_update`

Data type: `Hash`

hash to create reprepro::update resource
the name will be appended to $update

Default value: `{}`

##### <a name="create_filterlist"></a>`create_filterlist`

Data type: `Hash`

hash to create reprerpo::filterlist resource

Default value: `{}`

### <a name="repreprofilterlist"></a>`reprepro::filterlist`

Adds a FilterList

Packages list have the same syntax as the output of dpkg --get-selections

#### Examples

##### 

```puppet
reprepro::filterlist {"lenny-backports":
  ensure     => present,
  repository => "dev",
  packages   => [
    "git install",
    "git-email install",
    "gitk install",
  ],
}
```

#### Parameters

The following parameters are available in the `reprepro::filterlist` defined type:

* [`list_name`](#list_name)
* [`ensure`](#ensure)
* [`repository`](#repository)
* [`packages`](#packages)

##### <a name="list_name"></a>`list_name`

Data type: `String`

name of the filter list

Default value: `$title`

##### <a name="ensure"></a>`ensure`

Data type: `String`

present/absent, defaults to present

Default value: `'present'`

##### <a name="repository"></a>`repository`

Data type: `String`

the name of the repository

##### <a name="packages"></a>`packages`

Data type: `Array`

a list of packages, if the list is empty, the file
content won't be managed by puppet

Default value: `[]`

### <a name="repreprokey"></a>`reprepro::key`

Import a PGP key into the local keyring of the reprepro user

#### Parameters

The following parameters are available in the `reprepro::key` defined type:

* [`key_name`](#key_name)
* [`key_source`](#key_source)
* [`key_content`](#key_content)

##### <a name="key_name"></a>`key_name`

Data type: `String`

name of the key

Default value: `$title`

##### <a name="key_source"></a>`key_source`

Data type: `Optional[String]`

Path to the key in gpg --export format. This is
used as the source parameter in a puppet File resource.

Default value: ``undef``

##### <a name="key_content"></a>`key_content`

Data type: `Optional[String]`

define the key content instead of pointing to a source file

Default value: ``undef``

### <a name="reprepropull"></a>`reprepro::pull`

Add a repository pull rule.

#### Examples

##### 

```puppet
reprepro::pull {'lenny-backports':
  repository  => 'localpkgs',
  from        => 'dev',
  filter_name => 'lenny-backports',
}
```

#### Parameters

The following parameters are available in the `reprepro::pull` defined type:

* [`name`](#name)
* [`repository`](#repository)
* [`from`](#from)
* [`components`](#components)
* [`architectures`](#architectures)
* [`udebcomponents`](#udebcomponents)
* [`filter_action`](#filter_action)
* [`filter_name`](#filter_name)
* [`filter_src_name`](#filter_src_name)
* [`filter_formula`](#filter_formula)

##### <a name="name"></a>`name`

the name of the pull rule to use in the Pull
field in conf/distributions

##### <a name="repository"></a>`repository`

Data type: `String`

the local repository to pull to

##### <a name="from"></a>`from`

Data type: `String`

The codename of the distribution to pull packages from.

##### <a name="components"></a>`components`

Data type: `String`

The components of the distribution to get from.

Default value: `''`

##### <a name="architectures"></a>`architectures`

Data type: `String`

The architectures to update.

Default value: `''`

##### <a name="udebcomponents"></a>`udebcomponents`

Data type: `String`

Like Components but for the udebs.

Default value: `''`

##### <a name="filter_action"></a>`filter_action`

Data type: `String`

default action when something is not found in the list

Default value: `''`

##### <a name="filter_name"></a>`filter_name`

Data type: `String`

a list of filenames in the format of dpkg --get-selections

Default value: `''`

##### <a name="filter_src_name"></a>`filter_src_name`

Data type: `String`

FilterSrcList parameter

Default value: `''`

##### <a name="filter_formula"></a>`filter_formula`

Data type: `String`

FilterFormula

Default value: `''`

### <a name="repreprorepository"></a>`reprepro::repository`

Adds a packages repository.

#### Examples

##### 

```puppet
reprepro::repository { 'localpkgs':
  ensure  => present,
  options => ['verbose', 'basedir .'],
}
```

#### Parameters

The following parameters are available in the `reprepro::repository` defined type:

* [`repo_name`](#repo_name)
* [`ensure`](#ensure)
* [`incoming_name`](#incoming_name)
* [`incoming_dir`](#incoming_dir)
* [`incoming_tmpdir`](#incoming_tmpdir)
* [`incoming_allow`](#incoming_allow)
* [`options`](#options)
* [`createsymlinks`](#createsymlinks)
* [`documentroot`](#documentroot)
* [`max_files`](#max_files)
* [`distributions`](#distributions)
* [`distributions_defaults`](#distributions_defaults)

##### <a name="repo_name"></a>`repo_name`

Data type: `String`

the name of the repository

Default value: `$title`

##### <a name="ensure"></a>`ensure`

Data type: `String`

present/absent, defaults to present

Default value: `'present'`

##### <a name="incoming_name"></a>`incoming_name`

Data type: `String`

the name of the rule-set, used as argument

Default value: `'incoming'`

##### <a name="incoming_dir"></a>`incoming_dir`

Data type: `String`

the name of the directory to scan for .changes files

Default value: `'incoming'`

##### <a name="incoming_tmpdir"></a>`incoming_tmpdir`

Data type: `String`

directory where the files are copied into
before they are read

Default value: `'tmp'`

##### <a name="incoming_allow"></a>`incoming_allow`

Data type: `Variant[String, Array]`

allowed distributions

Default value: `''`

##### <a name="options"></a>`options`

Data type: `Array`

reprepro options

Default value: `['verbose', 'ask-passphrase', 'basedir .']`

##### <a name="createsymlinks"></a>`createsymlinks`

Data type: `Boolean`

create suite symlinks

Default value: ``false``

##### <a name="documentroot"></a>`documentroot`

Data type: `Optional[String]`

documentroot of the webserver (default undef)
if set, softlinks to the reprepro directories are made
the directory $documentroot must already exist

Default value: ``undef``

##### <a name="max_files"></a>`max_files`

Data type: `Optional[Integer]`

maximum number of file resources created for recursion
see puppet file resource, available only on puppet > 7

Default value: ``undef``

##### <a name="distributions"></a>`distributions`

Data type: `Hash`

hash to define distributions in this repository

Default value: `{}`

##### <a name="distributions_defaults"></a>`distributions_defaults`

Data type: `Hash`

defaults for all distributions in this repository

Default value: `{}`

### <a name="repreproupdate"></a>`reprepro::update`

Adds a packages repository.

#### Examples

##### 

```puppet
reprepro::update {"lenny-backports":
  suite       => 'lenny',
  repository  => "dev",
  url         => 'http://backports.debian.org/debian-backports',
  filter_name => "lenny-backports",
}
```

#### Parameters

The following parameters are available in the `reprepro::update` defined type:

* [`update_name`](#update_name)
* [`suite`](#suite)
* [`repository`](#repository)
* [`url`](#url)
* [`architectures`](#architectures)
* [`components`](#components)
* [`udebcomponents`](#udebcomponents)
* [`flat`](#flat)
* [`verify_release`](#verify_release)
* [`ignore_release`](#ignore_release)
* [`filter_action`](#filter_action)
* [`filter_name`](#filter_name)
* [`filter_src_name`](#filter_src_name)
* [`download_lists_as`](#download_lists_as)
* [`getinrelease`](#getinrelease)

##### <a name="update_name"></a>`update_name`

Data type: `String`

the name of the update-upstream use in the
Update field in conf/distributions

Default value: `$title`

##### <a name="suite"></a>`suite`

Data type: `String`

package suite

##### <a name="repository"></a>`repository`

Data type: `String`

the name of the repository

##### <a name="url"></a>`url`

Data type: `String`

a valid repository URL

##### <a name="architectures"></a>`architectures`

Data type: `Optional[String]`

architectures

Default value: ``undef``

##### <a name="components"></a>`components`

Data type: `Optional[String]`

components

Default value: ``undef``

##### <a name="udebcomponents"></a>`udebcomponents`

Data type: `Optional[String]`

udebcomponents

Default value: ``undef``

##### <a name="flat"></a>`flat`

Data type: `Optional[String]`

flat

Default value: ``undef``

##### <a name="verify_release"></a>`verify_release`

Data type: `String`

check the GPG signature Releasefile

Default value: `'blindtrust'`

##### <a name="ignore_release"></a>`ignore_release`

Data type: `String`

ignore_release

Default value: `'No'`

##### <a name="filter_action"></a>`filter_action`

Data type: `String`

default action when something is not found in the list

Default value: `''`

##### <a name="filter_name"></a>`filter_name`

Data type: `String`

Name of a filter list created with reprepro::filterlist,
matching binary packages

Default value: `''`

##### <a name="filter_src_name"></a>`filter_src_name`

Data type: `String`

Name of a filter list created with reprepro::filterlist,
matching source packages

Default value: `''`

##### <a name="download_lists_as"></a>`download_lists_as`

Data type: `String`

specify in which order reprepro will look for a usable
variant of needed index files ( .gz, .bz2, .lzma, .xz and .diff)

Default value: `''`

##### <a name="getinrelease"></a>`getinrelease`

Data type: `Optional[String]`

if this is set to 'no', no InRelease file is downloaded but
only Release (and Release.gpg ) are tried.

Default value: ``undef``

